clc
clear 
close all
addpath D:\001-tools\001-Matlab\m_map1.4\m_map
%%
model = 'EC-Earth3';
experiment='omip2';
%%
rEarth = 12735000/2.0;
T_ref = 0; S_ref = 34.8;
%%
file = ls(['../grid/thetao_Omon_' model '*.nc']);
file_t = ['../grid/' file];
info=ncinfo(file_t);
mask_2d = ncread(file_t,'thetao',[1,1,1,1],[Inf Inf 1,1],[1,1,1,1]);
lon  = ncread(file_t,'longitude');
lat  = ncread(file_t,'latitude');
lat_bnds = ncread(file_t,'vertices_latitude');
lon_bnds = ncread(file_t,'vertices_longitude');
dep = ncread(file_t,'lev');
dep_bnds = ncread(file_t,'lev_bnds');
dz = dep_bnds(2,:) - dep_bnds(1,:);
lat_bnds = reshape(lat_bnds,4,[]);
lon_bnds = reshape(lon_bnds,4,[]);
%%
alr=1;
if alr==0
    figure;
    m_proj('Azimuthal Equal-area','lon',0,'lat',90,'radius',40);
    [x_bnds y_bnds] = m_ll2xy(lon_bnds,lat_bnds);
    [x_cent y_cent] = m_ll2xy(lon,lat);
    patch(x_bnds,y_bnds,mask_2d(:)/1e14,'EdgeColor','r');
    caxis([-1 1])
    colorbar

    axis tight;
    hold on;
    m_scatter(lon(:),lat(:),2,'Filled');
    m_grid('xtick',[-180:45:180],'xticklabel',[],'ytick',[50:10:90],'yticklabel',[],'Color','b','LineStyle','none');
    title(['Zoom in for strait and press ENTER']);
    pause;
    loc = [];
    while(true)
        [x_sec,y_sec] = ginput(1);
        if(isempty(x_sec))
            break;
        else
            title('Pick up grid points. Press ENTER to stop!')
            [~,ind] = min(sqrt((x_cent(:)-x_sec).^2+(y_cent(:)-y_sec).^2));
            hold on;
            scatter(x_cent(ind),y_cent(ind),20,'k','Filled');
            loc = [loc ind];
            clear x_sec y_sec ind;
        end
    end
    strait=loc;
    save(model,'strait');
else
    load(model,'strait');
end
%%
file = ls(['../thetao_combine/thetao_Omon_' model '*.nc']);
to_file = ['../thetao_combine/' file]; file = ls(['../so_combine/so_Omon_' model '_*.nc']); so_file = ['../so_combine/' file];
file = ls(['../uo_combine/uo_Omon_' model '*.nc']);
uo_file = ['../uo_combine/' file];
file = ls(['../vo_combine/vo_Omon_' model '*.nc']);
vo_file = ['../vo_combine/' file];
disp(to_file)
disp(uo_file)
disp(vo_file)
%%
time = ncread(to_file,'time');
n=1;
for j=1:length(time)
    j
    to=ncread(to_file,'thetao',[1,1,1,j],[Inf Inf Inf,1],[1,1,1,1]); so=ncread(so_file,'so',[1,1,1,j],[Inf Inf Inf,1],[1,1,1,1]);
    vo=ncread(vo_file,'vo',    [1,1,1,j],[Inf Inf Inf,1],[1,1,1,1]);
    uo=ncread(uo_file,'uo',    [1,1,1,j],[Inf Inf Inf,1],[1,1,1,1]);

    u3d = reshape(uo,[],length(dep));
    v3d = reshape(vo,[],length(dep));
    t3d = reshape(to,[],length(dep)); s3d = reshape(so,[],length(dep));
    v2d = v3d(strait,:);
    u2d = u3d(strait,:);
    t2d = t3d(strait,:); s2d = s3d(strait,:);

    dx = [];
    for inod = 1:length(strait)
        nod_lons = lon_bnds(:,strait(inod));
        nod_lats = lat_bnds(:,strait(inod));
        lon1 = nod_lons(3); lat1 = nod_lats(3);
        lon2 = nod_lons(4); lat2 = nod_lats(4);
        dx = [dx rEarth*acos(cosd(lat1)*cosd(lat2)*cosd(lon1-lon2)+sind(lat1)*sind(lat2))];
    end
    dx = dx';
    dxx = repmat(dx,1,length(dep));
    dzz = repmat(dz,length(strait),1);
    dA  = dxx.*dzz;
    loc1 = find(v2d>0);
    loc2 = find(v2d<0);

    vol_trans_net_v(n) = nansum(nansum(v2d.*dA));            % net
    vol_trans_in_v( n) = nansum(nansum(v2d(loc1).*dA(loc1)));% in
    vol_trans_out_v(n) = nansum(nansum(v2d(loc2).*dA(loc2)));% out

    ht_trans_net_v(n)  = 4.2e6*nansum(nansum(v2d.*dA.*(t2d-T_ref)));                  % net
    ht_trans_in_v( n)  = 4.2e6*nansum(nansum(v2d(loc1).*dA(loc1).*(t2d(loc1)-T_ref)));% in 
    ht_trans_out_v(n)  = 4.2e6*nansum(nansum(v2d(loc2).*dA(loc2).*(t2d(loc2)-T_ref)));% out
    
    fw_trans_net_v(n) = nansum(nansum(v2d.*dA.*(S_ref-s2d)/S_ref));                  % net
    fw_trans_in_v(n)  = nansum(nansum(v2d(loc1).*dA(loc1).*(S_ref-s2d(loc1))/S_ref));% in
    fw_trans_out_v(n) = nansum(nansum(v2d(loc2).*dA(loc2).*(S_ref-s2d(loc2))/S_ref));% out

    dy = [];
    for inod = 1:length(strait)
        nod_lons = lon_bnds(:,strait(inod));
        nod_lats = lat_bnds(:,strait(inod));
        lon1 = nod_lons(2); lat1 = nod_lats(2);
        lon2 = nod_lons(3); lat2 = nod_lats(3);
        dy = [dy rEarth*acos(cosd(lat1)*cosd(lat2)*cosd(lon1-lon2)+sind(lat1)*sind(lat2))];
    end

    dy = dy';
    dyy = repmat(dy,1,length(dep));
    dzz = repmat(dz,length(strait),1);
    dA  = dyy.*dzz;
    loc1 = find(u2d>0);
    loc2 = find(u2d<0);

    vol_trans_net_u(n) = nansum(nansum(u2d.*dA));            % net
    vol_trans_in_u( n) = nansum(nansum(u2d(loc1).*dA(loc1)));% in
    vol_trans_out_u(n) = nansum(nansum(u2d(loc2).*dA(loc2)));% out

    ht_trans_net_u(n)  = 4.2e6*nansum(nansum(u2d.*dA.*(t2d-T_ref)));                  % net
    ht_trans_in_u( n)  = 4.2e6*nansum(nansum(u2d(loc1).*dA(loc1).*(t2d(loc1)-T_ref)));% in 
    ht_trans_out_u(n)  = 4.2e6*nansum(nansum(u2d(loc2).*dA(loc2).*(t2d(loc2)-T_ref)));% out
    
    fw_trans_net_u(n) = nansum(nansum(u2d.*dA.*(S_ref-s2d)/S_ref));                  % net
    fw_trans_in_u(n)  = nansum(nansum(u2d(loc1).*dA(loc1).*(S_ref-s2d(loc1))/S_ref));% in
    fw_trans_out_u(n) = nansum(nansum(u2d(loc2).*dA(loc2).*(S_ref-s2d(loc2))/S_ref));% out
    n=n+1;
end

vol_trans_net = vol_trans_net_u + vol_trans_net_v;
vol_trans_in  = vol_trans_in_u  + vol_trans_in_v;
vol_trans_out = vol_trans_out_u + vol_trans_out_v;

ht_trans_net = ht_trans_net_u + ht_trans_net_v;
ht_trans_in  = ht_trans_in_u  + ht_trans_in_v;
ht_trans_out = ht_trans_out_u + ht_trans_out_v;

fw_trans_net = fw_trans_net_u + fw_trans_net_v;
fw_trans_in  = fw_trans_in_u  + fw_trans_in_v;
fw_trans_out = fw_trans_out_u + fw_trans_out_v;

save([model '_transport'],'vol_trans_net','vol_trans_in','vol_trans_out','ht_trans_net','ht_trans_in','ht_trans_out','fw_trans_net','fw_trans_in','fw_trans_out');
%%
load([model '_transport']);
for i=1:length(vol_trans_net)/12
    annual(i)=mean(vol_trans_net(1+(i-1)*12:12+(i-1)*12))/1e6;
end
t=1958:2018;
plot(t,annual)

